@@ -27,10 +27,16 @@ if ($virt) {
 			}
 		}
 
-	# Also check for FPM socket in a FilesMatch block
+	# Also check for FPM socket in a FilesMatch block (possibly inside
+	# an If)
 	foreach my $f (&apache::find_directive_struct("FilesMatch", $vconf)) {
 		next if ($f->{'words'}->[0] ne '\.php$');
-		foreach my $h (&apache::find_directive("SetHandler", $f->{'members'})) {
+		my @shm = @{$f->{'members'}};
+		foreach my $i (&apache::find_directive_struct(
+				"If", $f->{'members'})) {
+			push(@shm, @{$i->{'members'}});
+			}
+		foreach my $h (&apache::find_directive("SetHandler", \@shm)) {
 			if ($h =~ /proxy:fcgi:\/\/(localhost|127\.0\.0\.1)/ ||
 			    $h =~ /proxy:unix:/) {
 				return 'fpm';
@@ -1029,7 +1035,8 @@ return { 'mod_php' => 0,
 	 'cgi' => 1,
 	 'fcgid' => 2,
 	 'fpm' => 3,
-	 'none' => 4, };
+	 'none' => 4,
+	 '' => 5, };
 }
 
 # list_available_php_versions([&domain], [forcemode|"all"])
@@ -2410,8 +2417,11 @@ foreach my $p (&apache::find_directive("ProxyPassMatch", $vconf)) {
 	}
 foreach my $f (&apache::find_directive_struct("FilesMatch", $vconf)) {
 	next if ($f->{'words'}->[0] ne '\.php$');
-	foreach my $h (&apache::find_directive("SetHandler",
-					       $f->{'members'})) {
+	my @shm = @{$f->{'members'}};
+	foreach my $i (&apache::find_directive_struct("If", $f->{'members'})) {
+	        push(@shm, @{$i->{'members'}});
+		}
+	foreach my $h (&apache::find_directive("SetHandler", \@shm)) {
 		if ($h =~ /proxy:fcgi:\/\/localhost:(\d+)/ ||
 		    $h =~ /proxy:fcgi:\/\/127\.0\.0\.1:(\d+)/ ||
 		    $h =~ /proxy:unix:([^\|]+)/) {
